#!/usr/bin/env bash

#
# Copyright 2011, Shark Intelligence, s.r.o.
# Released under the MIT license
#

#-------------------------------------------------------------------------------
# Configuration
#-------------------------------------------------------------------------------

# ITC user name
USER_NAME="myItcAccountEmail@my_domain.com"

# ITC user password
USER_PASSWD="mySuperSecretPassword"

# vendorid: find it at: https://reportingitc.apple.com/subdashboard.faces
VENDOR_ID="nnnnnnnn"

# directory where the reports are downloaded; Current dir is used if empty;
DIR_DEST=/add/your/directory/here

# number of days beginning with yesterday which the reports are downloaded for
NUM_OF_DAYS_TO_DOWNLOAD=14

# Currently only Sales reports are supported
REPORT_TYPE="S"

# Currently only Daily report frequency is supported
REPORT_FREQ="D"

#-------------------------------------------------------------------------------
# Program start
#-------------------------------------------------------------------------------

# Adjust input vars
#
if [ -z "$DIR_DEST" ]; then DIR_DEST=`pwd -P`; fi

# Print info
#
echo Downloading ITC sales reports for $NUM_OF_DAYS_TO_DOWNLOAD days into destination: $DIR_DEST

# set CLASSPATH which should point the this script location
#
THIS_SCRIPT=$0
cd `dirname $THIS_SCRIPT`
CLASSPATH=`pwd -P`

# set dir where the reports are downloaded to
#
cd $DIR_DEST

# loop for requested NUM_OF_DAYS_TO_DOWNLOAD
#
for (( DAY=NUM_OF_DAYS_TO_DOWNLOAD; DAY>0; DAY-- ))
do

DT_CUR_STR="date -v-${DAY}d +%Y%m%d"
DT_CUR=`$DT_CUR_STR`
FILE_CUR="${REPORT_TYPE}_${REPORT_FREQ}_${VENDOR_ID}_${DT_CUR}*.txt.gz"

if [ $(find . -name $FILE_CUR -maxdepth 1 -type f | wc -l) == "0" ]
then

# Report is missing so download one
#
echo $DT_CUR: MISSING! Download initiated...
java -cp $CLASSPATH Autoingestion $USER_NAME $USER_PASSWD $VENDOR_ID Sales Daily Summary $DT_CUR

else

# Report is found
#
echo "$DT_CUR: already here"

fi

done
